summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xconstants/battle_tower_constants.asm2
-rw-r--r--constants/radio_constants.asm6
-rw-r--r--data/battle/battle_text.asm20
-rw-r--r--data/common_text/common_text_1.asm2
-rw-r--r--data/common_text/common_text_2.asm10
-rw-r--r--data/common_text/common_text_3.asm6
-rw-r--r--data/predef_pointers.asm12
-rw-r--r--data/radio/oaks_pkmn_talk_routes.asm4
-rw-r--r--docs/bugs_and_glitches.md2
-rw-r--r--engine/battle/ai/items.asm2
-rw-r--r--engine/battle/core.asm142
-rwxr-xr-xengine/billspc.asm18
-rwxr-xr-xengine/billspctop.asm18
-rwxr-xr-xengine/breeding.asm2
-rwxr-xr-xengine/events/battle_tower/battle_tower.asm36
-rw-r--r--engine/events/battle_tower/load_trainer.asm100
-rw-r--r--engine/events/battle_tower/rules.asm18
-rwxr-xr-xengine/events/daycare.asm2
-rwxr-xr-xengine/events/poisonstep.asm2
-rwxr-xr-xengine/evolve.asm4
-rw-r--r--engine/item_effects.asm14
-rwxr-xr-xengine/link.asm6
-rw-r--r--engine/mon_stats.asm2
-rwxr-xr-xengine/move_mon.asm50
-rw-r--r--engine/pack.asm8
-rwxr-xr-xengine/pokegear.asm8
-rwxr-xr-xengine/print_party.asm4
-rw-r--r--engine/radio.asm78
-rw-r--r--engine/routines/correcterrorsinplayerparty.asm2
-rw-r--r--engine/save.asm10
-rwxr-xr-xengine/start_menu.asm4
-rwxr-xr-xengine/stats_screen.asm2
-rw-r--r--engine/tempmon.asm14
-rwxr-xr-xmacros/wram.asm18
-rw-r--r--maps/BattleTower1F.asm10
-rw-r--r--maps/BattleTowerBattleRoom.asm2
-rwxr-xr-xmobile/mobile_46.asm4
-rwxr-xr-xmobile/mobile_5c.asm2
-rw-r--r--mobile/mobile_5f.asm4
-rw-r--r--sram.asm14
-rw-r--r--wram.asm2
41 files changed, 333 insertions, 333 deletions
diff --git a/constants/battle_tower_constants.asm b/constants/battle_tower_constants.asm
index 71b8de8be..5a4048550 100755
--- a/constants/battle_tower_constants.asm
+++ b/constants/battle_tower_constants.asm
@@ -1,7 +1,7 @@
BATTLETOWER_PARTY_LENGTH EQU 3
BATTLETOWER_STREAK_LENGTH EQU 7
-BATTLETOWER_NUM_UNIQUE_PKMN EQU 21
+BATTLETOWER_NUM_UNIQUE_MON EQU 21
BATTLETOWER_NUM_UNIQUE_TRAINERS EQU 70
BATTLETOWER_TRAINERDATALENGTH EQU $24
diff --git a/constants/radio_constants.asm b/constants/radio_constants.asm
index d3f14e34c..8903ef005 100644
--- a/constants/radio_constants.asm
+++ b/constants/radio_constants.asm
@@ -97,7 +97,7 @@
; PlayRadio.StationPointers indexes (see engine/pokegear.asm)
const_def
const MAPRADIO_POKEMON_CHANNEL
- const MAPRADIO_OAKS_MON_TALK
+ const MAPRADIO_OAKS_POKEMON_TALK
const MAPRADIO_POKEDEX_SHOW
const MAPRADIO_POKEMON_MUSIC
const MAPRADIO_LUCKY_CHANNEL
@@ -108,8 +108,8 @@
; These tables in engine/radio.asm are all sized to a power of 2
; so there's no need for a rejection sampling loop
-NUM_OAKS_MON_TALK_ADVERBS EQU 16 ; OaksPkmnTalk8.Adverbs
-NUM_OAKS_MON_TALK_ADJECTIVES EQU 16 ; OaksPkmnTalk9.Adjectives
+NUM_OAKS_POKEMON_TALK_ADVERBS EQU 16 ; OaksPKMNTalk8.Adverbs
+NUM_OAKS_POKEMON_TALK_ADJECTIVES EQU 16 ; OaksPKMNTalk9.Adjectives
NUM_PNP_PEOPLE_ADJECTIVES EQU 16 ; PeoplePlaces5.Adjectives
NUM_PNP_PLACES_ADJECTIVES EQU 16 ; PeoplePlaces7.Adjectives
diff --git a/data/battle/battle_text.asm b/data/battle/battle_text.asm
index 1a609b476..9508c8c80 100644
--- a/data/battle/battle_text.asm
+++ b/data/battle/battle_text.asm
@@ -137,14 +137,14 @@ BattleText_SafeguardFaded: ; 0x808d2
prompt
; 0x808e7
-BattleText_PkmnLightScreenFell: ; 0x808e7
+BattleText_MonsLightScreenFell: ; 0x808e7
text_from_ram wStringBuffer1
text " #MON's"
line "LIGHT SCREEN fell!"
prompt
; 0x80905
-BattleText_PkmnReflectFaded: ; 0x80905
+BattleText_MonsReflectFaded: ; 0x80905
text_from_ram wStringBuffer1
text " #MON's"
line "REFLECT faded!"
@@ -186,7 +186,7 @@ BattleText_TheSandstormSubsided: ; 0x8098f
prompt
; 0x809a8
-BattleText_EnemyPkmnFainted: ; 0x809a8
+BattleText_EnemyMonFainted: ; 0x809a8
text "Enemy @"
text_from_ram wEnemyMonNick
text_start
@@ -236,7 +236,7 @@ BattleText_0x80a4f: ; 0x80a4f
prompt
; 0x80a75
-BattleText_PkmnFainted: ; 0x80a75
+BattleText_MonFainted: ; 0x80a75
text_from_ram wBattleMonNick
text_start
line "fainted!"
@@ -261,7 +261,7 @@ LostAgainstText: ; 0x80ab9
prompt
; 0x80aca
-BattleText_EnemyIsAboutToUseWillPlayerChangePkmn: ; 0x80aca
+BattleText_EnemyIsAboutToUseWillPlayerChangeMon: ; 0x80aca
text "<ENEMY>"
line "is about to use"
cont "@"
@@ -353,14 +353,14 @@ BattleText_ItemsCantBeUsedHere: ; 0x80bf3
prompt
; 0x80c0d
-BattleText_PkmnIsAlreadyOut: ; 0x80c0d
+BattleText_MonIsAlreadyOut: ; 0x80c0d
text_from_ram wBattleMonNick
text_start
line "is already out."
prompt
; 0x80c22
-BattleText_PkmnCantBeRecalled: ; 0x80c22
+BattleText_MonCantBeRecalled: ; 0x80c22
text_from_ram wBattleMonNick
text_start
line "can't be recalled!"
@@ -379,7 +379,7 @@ BattleText_TheMoveIsDisabled: ; 0x80c5b
prompt
; 0x80c72
-BattleText_PkmnHasNoMovesLeft: ; 0x80c72
+BattleText_MonHasNoMovesLeft: ; 0x80c72
text_from_ram wBattleMonNick
text_start
line "has no moves left!"
@@ -402,7 +402,7 @@ BattleText_StringBuffer1GrewToLevel: ; 0x80c9c
db "@@"
; 0x80cb9
-BattleText_WildPkmnIsEating: ; 0x80cba
+BattleText_WildMonIsEating: ; 0x80cba
text "Wild @"
text_from_ram wEnemyMonNick
text_start
@@ -410,7 +410,7 @@ BattleText_WildPkmnIsEating: ; 0x80cba
prompt
; 0x80cd1
-BattleText_WildPkmnIsAngry: ; 0x80cd1
+BattleText_WildMonIsAngry: ; 0x80cd1
text "Wild @"
text_from_ram wEnemyMonNick
text_start
diff --git a/data/common_text/common_text_1.asm b/data/common_text/common_text_1.asm
index 80b47013d..a6e867498 100644
--- a/data/common_text/common_text_1.asm
+++ b/data/common_text/common_text_1.asm
@@ -1121,7 +1121,7 @@ Text_RemainingTime::
text "Remaining Time"
done
-Text_YourPkmnsHPWasHealed::
+Text_YourMonsHPWasHealed::
text "Your #MON's HP"
line "was healed."
prompt
diff --git a/data/common_text/common_text_2.asm b/data/common_text/common_text_2.asm
index 183d254fc..12600c443 100644
--- a/data/common_text/common_text_2.asm
+++ b/data/common_text/common_text_2.asm
@@ -113,17 +113,17 @@ Text_StringBuffer2ExpPoints::
text " EXP. Points!"
prompt
-Text_GoPkmn::
+Text_GoMon::
text "Go! @@"
-Text_DoItPkmn::
+Text_DoItMon::
text "Do it! @@"
-Text_GoForItPkmn::
+Text_GoForItMon::
text "Go for it,"
line "@@"
-Text_YourFoesWeakGetmPkmn::
+Text_YourFoesWeakGetmMon::
text "Your foe's weak!"
line "Get'm, @@"
@@ -618,7 +618,7 @@ UnknownText_0x1c0bee::
cont "time to use that!"
prompt
-Text_YouDontHaveAPkmn::
+Text_YouDontHaveAMon::
text "You don't have a"
line "#MON!"
prompt
diff --git a/data/common_text/common_text_3.asm b/data/common_text/common_text_3.asm
index 7724775a4..4ed12258b 100644
--- a/data/common_text/common_text_3.asm
+++ b/data/common_text/common_text_3.asm
@@ -1139,14 +1139,14 @@ UnknownText_0x1c59a3::
para ""
done
-Text_OnlyThreePkmnMayBeEntered::
+Text_OnlyThreeMonMayBeEntered::
text "Only three #MON"
line "may be entered."
para ""
done
-Text_ThePkmnMustAllBeDifferentKinds::
+Text_TheMonMustAllBeDifferentKinds::
text "The @"
text_from_ram wStringBuffer2
text " #MON"
@@ -1156,7 +1156,7 @@ Text_ThePkmnMustAllBeDifferentKinds::
para ""
done
-Text_ThePkmnMustNotHoldTheSameItems::
+Text_TheMonMustNotHoldTheSameItems::
text "The @"
text_from_ram wStringBuffer2
text " #MON"
diff --git a/data/predef_pointers.asm b/data/predef_pointers.asm
index 16281d035..3a14a19ee 100644
--- a/data/predef_pointers.asm
+++ b/data/predef_pointers.asm
@@ -15,19 +15,19 @@ PredefPointers:: ; 856b
add_predef FillPP
add_predef TryAddMonToParty
add_predef AddTempmonToParty
- add_predef SendGetPkmnIntoFromBox
- add_predef SendPkmnIntoBox
+ add_predef SendGetMonIntoFromBox
+ add_predef SendMonIntoBox
add_predef GiveEgg
add_predef AnimateHPBar
- add_predef CalcPkmnStats
- add_predef CalcPkmnStatC
+ add_predef CalcMonStats
+ add_predef CalcMonStatC
add_predef CanLearnTMHMMove
add_predef GetTMHMMove
add_predef LinkTextboxAtHL ; $ 10
add_predef PrintMoveDesc
add_predef UpdatePlayerHUD
add_predef PlaceGraphic
- add_predef CheckPlayerPartyForFitPkmn
+ add_predef CheckPlayerPartyForFitMon
add_predef UpdateEnemyHUD
add_predef StartBattle
add_predef FillInExpBar
@@ -38,7 +38,7 @@ PredefPointers:: ; 856b
add_predef EvolveAfterBattle
add_predef TradeAnimationPlayer2
add_predef TradeAnimation
- add_predef CopyPkmnToTempMon
+ add_predef CopyMonToTempMon
add_predef ListMoves ; $20
add_predef PlaceNonFaintStatus
add_predef Unused_PlaceEnemyHPLevel
diff --git a/data/radio/oaks_pkmn_talk_routes.asm b/data/radio/oaks_pkmn_talk_routes.asm
index ad7b6529d..56b679741 100644
--- a/data/radio/oaks_pkmn_talk_routes.asm
+++ b/data/radio/oaks_pkmn_talk_routes.asm
@@ -1,6 +1,6 @@
; Oak's Pokémon Talk will list wild Pokémon on these maps.
-OaksPkmnTalkRoutes:
+OaksPKMNTalkRoutes:
map ROUTE_29
map ROUTE_46
map ROUTE_30
@@ -16,4 +16,4 @@ OaksPkmnTalkRoutes:
map ROUTE_45
map ROUTE_36
map ROUTE_31
-OaksPkmnTalkRoutesEnd
+OaksPKMNTalkRoutesEnd
diff --git a/docs/bugs_and_glitches.md b/docs/bugs_and_glitches.md
index 5abf9d08a..24b147942 100644
--- a/docs/bugs_and_glitches.md
+++ b/docs/bugs_and_glitches.md
@@ -261,7 +261,7 @@ This is a bug with `CheckPlayerHasUsableMoves` in [engine/battle/core.asm](/engi
ret nz
.force_struggle
- ld hl, BattleText_PkmnHasNoMovesLeft
+ ld hl, BattleText_MonHasNoMovesLeft
call StdBattleTextBox
ld c, 60
call DelayFrames
diff --git a/engine/battle/ai/items.asm b/engine/battle/ai/items.asm
index 4d1eea2e8..8fb420bd6 100644
--- a/engine/battle/ai/items.asm
+++ b/engine/battle/ai/items.asm
@@ -74,7 +74,7 @@ SwitchOften: ; 38045
ld a, [wEnemySwitchMonParam]
and $f
inc a
- ; In register 'a' is the number (1-6) of the Pkmn to switch to
+ ; In register 'a' is the number (1-6) of the mon to switch to
ld [wEnemySwitchMonIndex], a
jp AI_TrySwitch
; 38083
diff --git a/engine/billspc.asm b/engine/billspc.asm
index 9db6413c3..639db4205 100755
--- a/engine/billspc.asm
+++ b/engine/billspc.asm
@@ -591,7 +591,7 @@ _MovePKMNWithoutMail: ; e2759
ld a, [hl]
and A_BUTTON
jr nz, .a_button
- call MovePkmnWithoutMail_DPad
+ call MoveMonWithoutMail_DPad
jr c, .d_pad
and a
ret z
@@ -750,7 +750,7 @@ _MovePKMNWithoutMail: ; e2759
ld a, [hl]
and A_BUTTON
jr nz, .a_button_2
- call MovePkmnWithoutMail_DPad_2
+ call MoveMonWithoutMail_DPad_2
jr c, .dpad_2
and a
ret z
@@ -862,7 +862,7 @@ Withdraw_UpDown: ; e29b5 (38:69b5)
jp BillsPC_JoypadDidNothing
; e29d0 (38:69d0)
-MovePkmnWithoutMail_DPad: ; e29d0
+MoveMonWithoutMail_DPad: ; e29d0
ld hl, hJoyLast
ld a, [wBillsPC_NumMonsOnScreen]
ld d, a
@@ -886,7 +886,7 @@ MovePkmnWithoutMail_DPad: ; e29d0
jr nz, BillsPC_PressRight
jr BillsPC_JoypadDidNothing
-MovePkmnWithoutMail_DPad_2: ; e29f4
+MoveMonWithoutMail_DPad_2: ; e29f4
ld hl, hJoyLast
ld a, [wBillsPC_NumMonsOnScreen]
ld d, a
@@ -1819,7 +1819,7 @@ DepositPokemon: ; e307c (38:707c)
call GetNick
ld a, PC_DEPOSIT
ld [wPokemonWithdrawDepositParameter], a
- predef SendGetPkmnIntoFromBox
+ predef SendGetMonIntoFromBox
jr c, .asm_boxisfull
xor a
ld [wPokemonWithdrawDepositParameter], a
@@ -1874,7 +1874,7 @@ TryWithdrawPokemon: ; e30fa (38:70fa)
call CloseSRAM
xor a
ld [wPokemonWithdrawDepositParameter], a
- predef SendGetPkmnIntoFromBox
+ predef SendGetMonIntoFromBox
jr c, .PartyFull
ld a, PC_DEPOSIT
ld [wPokemonWithdrawDepositParameter], a
@@ -2010,7 +2010,7 @@ MovePKMNWitoutMail_InsertMon: ; e31e7
.dw_return ; e322a
pop af
ld e, a
- farcall MovePkmnWOMail_InsertMon_SaveGame
+ farcall MoveMonWOMail_InsertMon_SaveGame
ret
; e3233
@@ -2095,7 +2095,7 @@ MovePKMNWitoutMail_InsertMon: ; e31e7
ld a, [wBillsPC_BackupLoadedBox]
dec a
ld e, a
- farcall MovePkmnWOMail_SaveGame
+ farcall MoveMonWOMail_SaveGame
ld a, [wBillsPC_BackupCursorPosition]
ld hl, wBillsPC_BackupScrollPosition
add [hl]
@@ -2123,7 +2123,7 @@ MovePKMNWitoutMail_InsertMon: ; e31e7
ld a, [wBillsPC_LoadedBox]
dec a
ld e, a
- farcall MovePkmnWOMail_SaveGame
+ farcall MoveMonWOMail_SaveGame
ld a, [wBillsPC_CursorPosition]
ld hl, wBillsPC_ScrollPosition
add [hl]
diff --git a/engine/billspctop.asm b/engine/billspctop.asm
index 2c0a110ba..8904aa4d6 100755
--- a/engine/billspctop.asm
+++ b/engine/billspctop.asm
@@ -117,7 +117,7 @@ BillsPC_MovePKMNMenu: ; e4cd
jr .quit
.no_mail
- farcall StartMovePkmnWOMail_SaveGame
+ farcall StartMoveMonWOMail_SaveGame
jr c, .quit
farcall _MovePKMNWithoutMail
call ReturnToMapFromSubmenu
@@ -145,30 +145,30 @@ BillsPC_DepositMenu: ; e4fe (3:64fe)
Unreferenced_Functione512:
ld a, [wPartyCount]
and a
- jr z, .no_pkmn
+ jr z, .no_mon
cp 2
- jr c, .only_one_pkmn
+ jr c, .only_one_mon
and a
ret
-.no_pkmn
- ld hl, .Text_NoPKMN
+.no_mon
+ ld hl, .Text_NoMon
call MenuTextBoxBackup
scf
ret
-.only_one_pkmn
- ld hl, .Text_ItsYourLastPKMN
+.only_one_mon
+ ld hl, .Text_ItsYourLastMon
call MenuTextBoxBackup
scf
ret
-.Text_NoPKMN: ; 0xe52e
+.Text_NoMon: ; 0xe52e
; You don't have a single #MON!
text_jump UnknownText_0x1c1062
db "@"
-.Text_ItsYourLastPKMN: ; 0xe533
+.Text_ItsYourLastMon: ; 0xe533
; You can't deposit your last #MON!
text_jump UnknownText_0x1c1080
db "@"
diff --git a/engine/breeding.asm b/engine/breeding.asm
index 7756d30ef..0efc10a44 100755
--- a/engine/breeding.asm
+++ b/engine/breeding.asm
@@ -289,7 +289,7 @@ HatchEggs: ; 16f70 (5:6f70)
ld bc, MON_STAT_EXP - 1
add hl, bc
ld b, $0
- predef CalcPkmnStats
+ predef CalcMonStats
pop bc
ld hl, MON_MAXHP
add hl, bc
diff --git a/engine/events/battle_tower/rules.asm b/engine/events/battle_tower/rules.asm
index fc9fa948a..3b0c9f930 100644
--- a/engine/events/battle_tower/rules.asm
+++ b/engine/events/battle_tower/rules.asm
@@ -56,9 +56,9 @@ CheckForBattleTowerRules: ; 8b201
.TextPointers: ; 8b222
dw JumpText_ExcuseMeYoureNotReady
- dw JumpText_OnlyThreePkmnMayBeEntered
- dw JumpText_ThePkmnMustAllBeDifferentKinds
- dw JumpText_ThePkmnMustNotHoldTheSameItems
+ dw JumpText_OnlyThreeMonMayBeEntered
+ dw JumpText_TheMonMustAllBeDifferentKinds
+ dw JumpText_TheMonMustNotHoldTheSameItems
dw JumpText_YouCantTakeAnEgg
; 8b22c
@@ -92,21 +92,21 @@ JumpText_EggDoesNotQualify: ; 0x8b242
db "@"
; 0x8b247
-JumpText_OnlyThreePkmnMayBeEntered: ; 0x8b247
+JumpText_OnlyThreeMonMayBeEntered: ; 0x8b247
; Only three #MON may be entered.
- text_jump Text_OnlyThreePkmnMayBeEntered
+ text_jump Text_OnlyThreeMonMayBeEntered
db "@"
; 0x8b24c
-JumpText_ThePkmnMustAllBeDifferentKinds: ; 0x8b24c
+JumpText_TheMonMustAllBeDifferentKinds: ; 0x8b24c
; The @ #MON must all be different kinds.
- text_jump Text_ThePkmnMustAllBeDifferentKinds
+ text_jump Text_TheMonMustAllBeDifferentKinds
db "@"
; 0x8b251
-JumpText_ThePkmnMustNotHoldTheSameItems: ; 0x8b251
+JumpText_TheMonMustNotHoldTheSameItems: ; 0x8b251
; The @ #MON must not hold the same items.
- text_jump Text_ThePkmnMustNotHoldTheSameItems
+ text_jump Text_TheMonMustNotHoldTheSameItems
db "@"
; 0x8b256
diff --git a/engine/events/daycare.asm b/engine/events/daycare.asm
index ed1b2ef2b..8dfdc8c47 100755
--- a/engine/events/daycare.asm
+++ b/engine/events/daycare.asm
@@ -567,7 +567,7 @@ DayCare_GiveEgg: ; 169ac
pop hl
push bc
ld b, $0
- predef CalcPkmnStats
+ predef CalcMonStats
pop bc
ld hl, MON_HP
add hl, bc
diff --git a/engine/events/poisonstep.asm b/engine/events/poisonstep.asm
index 47916076f..5ea094db9 100755
--- a/engine/events/poisonstep.asm
+++ b/engine/events/poisonstep.asm
@@ -145,7 +145,7 @@ DoPoisonStep:: ; 505da
ld a, [wPartyCount]
cp [hl]
jr nz, .party_loop
- predef CheckPlayerPartyForFitPkmn
+ predef CheckPlayerPartyForFitMon
ld a, d
ld [wScriptVar], a
ret
diff --git a/engine/evolve.asm b/engine/evolve.asm
index 5fb5aff46..efcc9c3f0 100755
--- a/engine/evolve.asm
+++ b/engine/evolve.asm
@@ -55,7 +55,7 @@ EvolveAfterBattle_MasterLoop
push hl
xor a
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
pop hl
.loop
@@ -265,7 +265,7 @@ EvolveAfterBattle_MasterLoop
ld hl, wTempMonExp + 2
ld de, wTempMonMaxHP
ld b, $1
- predef CalcPkmnStats
+ predef CalcMonStats
ld a, [wCurPartyMon]
ld hl, wPartyMons
diff --git a/engine/item_effects.asm b/engine/item_effects.asm
index 114b2cb70..7cf784636 100644
--- a/engine/item_effects.asm
+++ b/engine/item_effects.asm
@@ -623,7 +623,7 @@ ParkBall: ; e8a2
.SendToPC:
call ClearSprites
- predef SendPkmnIntoBox
+ predef SendMonIntoBox
farcall SetBoxMonCaughtData
@@ -1283,7 +1283,7 @@ UpdateStatsAfterItem: ; ee8c
ld a, MON_STAT_EXP - 1
call GetPartyParamLocation
ld b, $1
- predef_jump CalcPkmnStats
+ predef_jump CalcMonStats
; ee9f
RareCandy_StatBooster_ExitMenu: ; ee9f
@@ -1422,7 +1422,7 @@ RareCandy: ; ef14
xor a ; PARTYMON
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
hlcoord 9, 0
ld b, 10
@@ -1846,13 +1846,13 @@ UseItem_SelectMon: ; f1f9 (3:71f9)
push de
push bc
call ClearBGPalettes
- call ChoosePkmnToUseItemOn
+ call ChooseMonToUseItemOn
pop bc
pop de
pop hl
ret
-ChoosePkmnToUseItemOn: ; f21c (3:721c)
+ChooseMonToUseItemOn: ; f21c (3:721c)
farcall LoadPartyMenuGFX
farcall InitPartyMenuWithCancel
farcall InitPartyMenuGFX
@@ -2154,7 +2154,7 @@ Softboiled_MilkDrinkFunction: ; f3df (3:73df)
push bc
ld a, PARTYMENUACTION_HEALING_ITEM
ld [wPartyMenuActionText], a
- call ChoosePkmnToUseItemOn
+ call ChooseMonToUseItemOn
pop bc
jr c, .set_carry
ld a, [wPartyMenuCursor]
@@ -2475,7 +2475,7 @@ Mysteryberry: ; f5bf
ld [wd002], a
.loop
- ; Party Screen opens to choose on which Pkmn to use the Item
+ ; Party Screen opens to choose on which mon to use the Item
ld b, PARTYMENUACTION_HEALING_ITEM
call UseItem_SelectMon
jp c, PPRestoreItem_Cancel
diff --git a/engine/link.asm b/engine/link.asm
index 59d1a149a..4c22e18ea 100755
--- a/engine/link.asm
+++ b/engine/link.asm
@@ -790,7 +790,7 @@ Link_PrepPartyData_Gen1: ; 28499
add hl, bc
ld c, STAT_SATK
ld b, TRUE
- predef CalcPkmnStatC
+ predef CalcMonStatC
pop bc
pop de
@@ -1069,7 +1069,7 @@ Function2868a: ; 2868a
add hl, bc
ld c, STAT_SATK
ld b, TRUE
- predef CalcPkmnStatC
+ predef CalcMonStatC
pop bc
pop hl
ld a, [hQuotient + 1]
@@ -1082,7 +1082,7 @@ Function2868a: ; 2868a
add hl, bc
ld c, STAT_SDEF
ld b, TRUE
- predef CalcPkmnStatC
+ predef CalcMonStatC
pop bc
pop hl
ld a, [hQuotient + 1]
diff --git a/engine/mon_stats.asm b/engine/mon_stats.asm
index a06ad1a46..5ed15f4f5 100644
--- a/engine/mon_stats.asm
+++ b/engine/mon_stats.asm
@@ -343,7 +343,7 @@ Unused_PlaceEnemyHPLevel:
call GetNick
pop hl
call PlaceString
- call CopyPkmnToTempMon
+ call CopyMonToTempMon
pop hl
ld a, [wCurPartySpecies]
cp EGG
diff --git a/engine/move_mon.asm b/engine/move_mon.asm
index 47a00120b..a3600d2f0 100755
--- a/engine/move_mon.asm
+++ b/engine/move_mon.asm
@@ -1,5 +1,5 @@
TryAddMonToParty: ; d88c
-; Check if to copy wild Pkmn or generate new Pkmn
+; Check if to copy wild mon or generate a new one
; Whose is it?
ld de, wPartyCount
ld a, [wMonType]
@@ -259,7 +259,7 @@ endr
ld a, 1
ld c, a
ld b, FALSE
- call CalcPkmnStatC
+ call CalcMonStatC
ld a, [hProduct + 2]
ld [de], a
inc de
@@ -340,7 +340,7 @@ endr
ld bc, MON_STAT_EXP - 1
add hl, bc
ld b, FALSE
- call CalcPkmnStats
+ call CalcMonStats
.registerunowndex
ld a, [wMonType]
@@ -477,12 +477,12 @@ AddTempmonToParty: ; da96
and a
ret
-SendGetPkmnIntoFromBox: ; db3f
-; Sents/Gets Pkmn into/from Box depending on Parameter
-; wPokemonWithdrawDepositParameter == 0: get Pkmn into Party
-; wPokemonWithdrawDepositParameter == 1: sent Pkmn into Box
-; wPokemonWithdrawDepositParameter == 2: get Pkmn from DayCare
-; wPokemonWithdrawDepositParameter == 3: put Pkmn into DayCare
+SendGetMonIntoFromBox: ; db3f
+; Sents/Gets mon into/from Box depending on Parameter
+; wPokemonWithdrawDepositParameter == 0: get mon into Party
+; wPokemonWithdrawDepositParameter == 1: sent mon into Box
+; wPokemonWithdrawDepositParameter == 2: get mon from DayCare
+; wPokemonWithdrawDepositParameter == 3: put mon into DayCare
ld a, BANK(sBoxCount)
call GetSRAMBank
@@ -495,7 +495,7 @@ SendGetPkmnIntoFromBox: ; db3f
ld hl, wBreedMon1Species
jr z, .breedmon
- ; we want to sent a Pkmn into the Box
+ ; we want to sent a mon into the Box
; so check if there's enough space
ld hl, sBoxCount
ld a, [hl]
@@ -640,7 +640,7 @@ SendGetPkmnIntoFromBox: ; db3f
srl a
add $2
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
callfar CalcLevel
ld a, d
ld [wCurPartyLevel], a
@@ -659,8 +659,8 @@ SendGetPkmnIntoFromBox: ; db3f
add hl, bc
push bc
- ld b, $1
- call CalcPkmnStats
+ ld b, TRUE
+ call CalcMonStats
pop bc
ld a, [wPokemonWithdrawDepositParameter]
@@ -872,8 +872,8 @@ RetrieveBreedmon: ; dd64
ld hl, $a
add hl, bc
push bc
- ld b, $1
- call CalcPkmnStats
+ ld b, TRUE
+ call CalcMonStats
ld hl, wPartyMon1Moves
ld a, [wPartyCount]
dec a
@@ -947,8 +947,8 @@ DepositBreedmon: ; de44
ld bc, BOXMON_STRUCT_LENGTH
jp CopyBytes
-SendPkmnIntoBox: ; de6e
-; Sends the Pkmn into one of Bills Boxes
+SendMonIntoBox: ; de6e
+; Sends the mon into one of Bills Boxes
; the data comes mainly from 'wEnemyMon:'
ld a, BANK(sBoxCount)
call GetSRAMBank
@@ -1402,8 +1402,8 @@ ComputeNPCTrademonStats: ; e134
push de
ld a, MON_STAT_EXP - 1
call GetPartyParamLocation
- ld b, $1
- call CalcPkmnStats
+ ld b, TRUE
+ call CalcMonStats
pop de
ld a, MON_HP
call GetPartyParamLocation
@@ -1415,17 +1415,17 @@ ComputeNPCTrademonStats: ; e134
ret
; e167
-CalcPkmnStats: ; e167
-; Calculates all 6 Stats of a Pkmn
+CalcMonStats: ; e167
+; Calculates all 6 Stats of a mon
; b: Take into account stat EXP if TRUE
; 'c' counts from 1-6 and points with 'wBaseStats' to the base value
; hl is the path to the Stat EXP
-; results in $ffb5 and $ffb6 are saved in [de]
+; de points to where the final stats will be saved
ld c, $0
.loop
inc c
- call CalcPkmnStatC
+ call CalcMonStatC
ld a, [hMultiplicand + 1]
ld [de], a
inc de
@@ -1438,7 +1438,7 @@ CalcPkmnStats: ; e167
ret
; e17b
-CalcPkmnStatC: ; e17b
+CalcMonStatC: ; e17b
; 'c' is 1-6 and points to the BaseStat
; 1: HP
; 2: Attack
@@ -1669,7 +1669,7 @@ GivePoke:: ; e277
ld a, [wCurPartySpecies]
ld [wTempEnemyMonSpecies], a
callfar LoadEnemyMon
- call SendPkmnIntoBox
+ call SendMonIntoBox
jp nc, .FailedToGiveMon
ld a, BOXMON
ld [wMonType], a
diff --git a/engine/pack.asm b/engine/pack.asm
index dfe30612d..df0df21ec 100644
--- a/engine/pack.asm
+++ b/engine/pack.asm
@@ -494,7 +494,7 @@ UseItem: ; 10311
ret
.NoPokemon:
- ld hl, TextJump_YouDontHaveAPkmn
+ ld hl, TextJump_YouDontHaveAMon
call Pack_PrintTextNoScroll
ret
@@ -648,7 +648,7 @@ GiveItem: ; 103fd
ret
.NoPokemon: ; 10486 (4:4486)
- ld hl, TextJump_YouDontHaveAPkmn
+ ld hl, TextJump_YouDontHaveAMon
call Pack_PrintTextNoScroll
ret
; 1048d (4:448d)
@@ -1668,9 +1668,9 @@ Text_ThisIsntTheTime: ; 0x10af3
db "@"
; 0x10af8
-TextJump_YouDontHaveAPkmn: ; 0x10af8
+TextJump_YouDontHaveAMon: ; 0x10af8
; You don't have a #MON!
- text_jump Text_YouDontHaveAPkmn
+ text_jump Text_YouDontHaveAMon
db "@"
; 0x10afd
diff --git a/engine/pokegear.asm b/engine/pokegear.asm
index ea2afdc78..a50ad5ea1 100755
--- a/engine/pokegear.asm
+++ b/engine/pokegear.asm
@@ -1543,7 +1543,7 @@ RadioChannels:
; entries correspond to constants/radio_constants.asm
; frequency value given here = 4 × ingame_frequency − 2
- dbw 16, .PkmnTalkAndPokedexShow
+ dbw 16, .PKMNTalkAndPokedexShow
dbw 28, .PokemonMusic
dbw 32, .LuckyChannel
dbw 40, .BuenasPassword
@@ -1554,7 +1554,7 @@ RadioChannels:
dbw 80, .EvolutionRadio
db -1
-.PkmnTalkAndPokedexShow:
+.PKMNTalkAndPokedexShow:
; Pokédex Show in the morning
; Oak's Pokémon Talk in the afternoon and evening
@@ -1653,7 +1653,7 @@ LoadStation_OaksPokemonTalk: ; 91753 (24:5753)
ld a, BANK(PlayRadioShow)
ld hl, PlayRadioShow
call Radio_BackUpFarCallParams
- ld de, OaksPkmnTalkName
+ ld de, OaksPKMNTalkName
ret
LoadStation_PokedexShow: ; 91766 (24:5766)
@@ -1846,7 +1846,7 @@ NoRadioName: ; 918a9 (24:58a9)
; 918bf
-OaksPkmnTalkName: db "OAK's <PK><MN> Talk@"
+OaksPKMNTalkName: db "OAK's <PK><MN> Talk@"
PokedexShowName: db "#DEX Show@"
PokemonMusicName: db "#MON Music@"
LuckyChannelName: db "Lucky Channel@"
diff --git a/engine/print_party.asm b/engine/print_party.asm
index 5fe0e28c0..1095ce584 100755
--- a/engine/print_party.asm
+++ b/engine/print_party.asm
@@ -159,7 +159,7 @@ PrintPartyMonPage1: ; 1dc381
xor a
ld [wMonType], a
- farcall CopyPkmnToTempMon
+ farcall CopyMonToTempMon
hlcoord 0, 7
ld b, 9
ld c, 18
@@ -243,7 +243,7 @@ PrintPartyMonPage2: ; 1dc47b
call LoadFontsBattleExtra
xor a
ld [wMonType], a
- farcall CopyPkmnToTempMon
+ farcall CopyMonToTempMon
hlcoord 0, 0
ld b, 15
ld c, 18
diff --git a/engine/routines/correcterrorsinplayerparty.asm b/engine/routines/correcterrorsinplayerparty.asm
index 5f2bba6bc..d0091f3a4 100644
--- a/engine/routines/correcterrorsinplayerparty.asm
+++ b/engine/routines/correcterrorsinplayerparty.asm
@@ -90,7 +90,7 @@ Unreferenced_CorrectErrorsInPlayerParty:
ld hl, MON_STAT_EXP - 1
add hl, bc
ld b, $1
- predef CalcPkmnStats
+ predef CalcMonStats
pop hl
ld bc, PARTYMON_STRUCT_LENGTH
add hl, bc
diff --git a/engine/save.asm b/engine/save.asm
index c519e50ad..4699ed125 100644
--- a/engine/save.asm
+++ b/engine/save.asm
@@ -74,7 +74,7 @@ Link_SaveGame: ; 14ab2
ret
; 14ac2
-MovePkmnWOMail_SaveGame: ; 14ac2
+MoveMonWOMail_SaveGame: ; 14ac2
call PauseGameLogic
push de
call SaveBox
@@ -86,7 +86,7 @@ MovePkmnWOMail_SaveGame: ; 14ac2
ret
; 14ad5
-MovePkmnWOMail_InsertMon_SaveGame: ; 14ad5
+MoveMonWOMail_InsertMon_SaveGame: ; 14ad5
call PauseGameLogic
push de
call SaveBox
@@ -119,8 +119,8 @@ MovePkmnWOMail_InsertMon_SaveGame: ; 14ad5
ret
; 14b34
-StartMovePkmnWOMail_SaveGame: ; 14b34
- ld hl, Text_SaveOnMovePkmnWOMail
+StartMoveMonWOMail_SaveGame: ; 14b34
+ ld hl, Text_SaveOnMoveMonWOMail
call MenuTextBox
call YesNoBox
call ExitMenu
@@ -1203,7 +1203,7 @@ Text_SaveOnBoxSwitch: ; 0x152a1
db "@"
; 0x152a6
-Text_SaveOnMovePkmnWOMail: ; 0x152a6
+Text_SaveOnMoveMonWOMail: ; 0x152a6
; Each time you move a #MON, data will be saved. OK?
text_jump UnknownText_0x1c465f
db "@"
diff --git a/engine/start_menu.asm b/engine/start_menu.asm
index f0cacc5b1..e63e18bed 100755
--- a/engine/start_menu.asm
+++ b/engine/start_menu.asm
@@ -1788,7 +1788,7 @@ SetUpMoveScreenBG: ; 13172
hlcoord 5, 1
call PlaceString
push bc
- farcall CopyPkmnToTempMon
+ farcall CopyMonToTempMon
pop hl
call PrintLevel
ld hl, wPlayerHPPal
@@ -1805,7 +1805,7 @@ SetUpMoveList: ; 131ef
ld [hBGMapMode], a
ld [wMoveSwapBuffer], a
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
ld hl, wTempMonMoves
ld de, wListMoves_MoveIndicesBuffer
ld bc, NUM_MOVES
diff --git a/engine/stats_screen.asm b/engine/stats_screen.asm
index b3daadcc6..afbe20e01 100755
--- a/engine/stats_screen.asm
+++ b/engine/stats_screen.asm
@@ -240,7 +240,7 @@ StatsScreen_CopyToTempMon: ; 4ddf2 (13:5df2)
jr .done
.breedmon
- farcall CopyPkmnToTempMon
+ farcall CopyMonToTempMon
ld a, [wCurPartySpecies]
cp EGG
jr z, .done
diff --git a/engine/tempmon.asm b/engine/tempmon.asm
index 37b485e38..5bee7b06a 100644
--- a/engine/tempmon.asm
+++ b/engine/tempmon.asm
@@ -1,10 +1,10 @@
-CopyPkmnToTempMon: ; 5084a
-; gets the BaseData of a Pkmn
+CopyMonToTempMon: ; 5084a
+; gets the BaseData of a mon
; and copies the party_struct to wTempMon
ld a, [wCurPartyMon]
ld e, a
- call GetPkmnSpecies
+ call GetMonSpecies
ld a, [wCurPartySpecies]
ld [wCurSpecies], a
call GetBaseData
@@ -51,7 +51,7 @@ _TempMonStatsCalculation: ; 50893
add hl, bc
push bc
ld b, $1
- predef CalcPkmnStats
+ predef CalcMonStats
pop bc
ld hl, MON_HP
add hl, bc
@@ -82,9 +82,9 @@ _TempMonStatsCalculation: ; 50893
ld [hl], a
ret
-GetPkmnSpecies: ; 508d5
-; [wMonType] has the type of the Pkmn
-; e = Nr. of Pkmn (i.e. [wCurPartyMon])
+GetMonSpecies: ; 508d5
+; [wMonType] has the type of the mon
+; e = Nr. of mon (i.e. [wCurPartyMon])
ld a, [wMonType]
and a ; PARTYMON
diff --git a/macros/wram.asm b/macros/wram.asm
index 7c8ca44a1..136e42e6a 100755
--- a/macros/wram.asm
+++ b/macros/wram.asm
@@ -178,15 +178,15 @@ ENDM
battle_tower_struct: MACRO
\1Name:: ds NAME_LENGTH +- 1
\1TrainerClass:: ds 1
-\1Pkmn1:: party_struct \1Pkmn1
-\1Pkmn1Name:: ds MON_NAME_LENGTH
-\1Pkmn1NameEnd::
-\1Pkmn2:: party_struct \1Pkmn2
-\1Pkmn2Name:: ds MON_NAME_LENGTH
-\1Pkmn2NameEnd::
-\1Pkmn3:: party_struct \1Pkmn3
-\1Pkmn3Name:: ds MON_NAME_LENGTH
-\1Pkmn3NameEnd::
+\1Mon1:: party_struct \1Mon1
+\1Mon1Name:: ds MON_NAME_LENGTH
+\1Mon1NameEnd::
+\1Mon2:: party_struct \1Mon2
+\1Mon2Name:: ds MON_NAME_LENGTH
+\1Mon2NameEnd::
+\1Mon3:: party_struct \1Mon3
+\1Mon3Name:: ds MON_NAME_LENGTH
+\1Mon3NameEnd::
\1TrainerData:: ds BATTLETOWER_TRAINERDATALENGTH
\1TrainerEnd::
ENDM
diff --git a/maps/BattleTower1F.asm b/maps/BattleTower1F.asm
index 910d27a69..e4edf7b04 100644
--- a/maps/BattleTower1F.asm
+++ b/maps/BattleTower1F.asm
@@ -188,7 +188,7 @@ UnreferencedScript_0x9e4be:
UnreferencedScript_0x9e4ea:
writebyte BATTLETOWERACTION_LEVEL_CHECK
special Special_BattleTowerAction
- if_not_equal $0, Script_APkmnLevelExceeds
+ if_not_equal $0, Script_AMonLevelExceeds
writebyte BATTLETOWERACTION_UBERS_CHECK
special Special_BattleTowerAction
if_not_equal $0, Script_MayNotEnterABattleRoomUnderL70
@@ -225,8 +225,8 @@ UnreferencedScript_0x9e53b:
waitbutton
jump Script_BattleTowerHopeToServeYouAgain
-Script_APkmnLevelExceeds: ; 0x9e542
- writetext Text_APkmnLevelExceeds
+Script_AMonLevelExceeds: ; 0x9e542
+ writetext Text_AMonLevelExceeds
waitbutton
jump Script_Menu_ChallengeExplanationCancel
@@ -628,7 +628,7 @@ Text_BattleTower_LeftWithoutSaving:
line "invalid."
done
-Text_YourPkmnWillBeHealedToFullHealth: ; 0x9ee92
+Text_YourMonWillBeHealedToFullHealth: ; 0x9ee92
text "Your #MON will"
line "be healed to full"
cont "health."
@@ -732,7 +732,7 @@ Text_RegisterRecordTimedOut_Mobile:
cont "challenge."
done
-Text_APkmnLevelExceeds: ; 0x9f1e5
+Text_AMonLevelExceeds: ; 0x9f1e5
text "One or more of"
line "your #MON's"
cont "levels exceeds @"
diff --git a/maps/BattleTowerBattleRoom.asm b/maps/BattleTowerBattleRoom.asm
index dd8e08e0f..de86e6eee 100644
--- a/maps/BattleTowerBattleRoom.asm
+++ b/maps/BattleTowerBattleRoom.asm
@@ -44,7 +44,7 @@ Script_BattleRoomLoop: ; 0x9f425
applymovement BATTLETOWERBATTLEROOM_RECEPTIONIST, MovementData_BattleTowerBattleRoomReceptionistWalksToPlayer
applymovement PLAYER, MovementData_BattleTowerBattleRoomPlayerTurnsToFaceReceptionist
opentext
- writetext Text_YourPkmnWillBeHealedToFullHealth
+ writetext Text_YourMonWillBeHealedToFullHealth
waitbutton
closetext
playmusic MUSIC_HEAL
diff --git a/mobile/mobile_46.asm b/mobile/mobile_46.asm
index 0298c075b..670dd1a6e 100755
--- a/mobile/mobile_46.asm
+++ b/mobile/mobile_46.asm
@@ -7146,7 +7146,7 @@ Function11b483: ; 11b483
pop de
push de
ld b, OTPARTYMON
- predef CalcPkmnStats
+ predef CalcMonStats
pop de
ld h, d
ld l, e
@@ -7565,7 +7565,7 @@ Function11b6b4: ; 11b6b4
ld hl, $c60d + MON_STAT_EXP - 1
ld de, $c60d + MON_MAXHP
ld b, $1
- predef CalcPkmnStats
+ predef CalcMonStats
ld de, $c60d + MON_MAXHP
ld hl, $c60d + MON_HP
ld a, [de]
diff --git a/mobile/mobile_5c.asm b/mobile/mobile_5c.asm
index 474dde270..ec5b5428d 100755
--- a/mobile/mobile_5c.asm
+++ b/mobile/mobile_5c.asm
@@ -220,7 +220,7 @@ Function170c8b: ; 170c8b
CheckBTMonMovesForErrors: ; 170c98
ld c, BATTLETOWER_PARTY_LENGTH
- ld hl, wBT_OTTempPkmn1Moves
+ ld hl, wBT_OTTempMon1Moves
.loop
push hl
ld a, [hl]
diff --git a/mobile/mobile_5f.asm b/mobile/mobile_5f.asm
index be9578d22..25f410349 100644
--- a/mobile/mobile_5f.asm
+++ b/mobile/mobile_5f.asm
@@ -2442,7 +2442,7 @@ Function17ded9: ; 17ded9
ld e, l
push hl
ld b, $0
- farcall CalcPkmnStats
+ farcall CalcMonStats
ld a, [wPartyCount]
dec a
ld hl, wPartyMon1HP
@@ -2531,7 +2531,7 @@ Function17e026: ; 17e026
push bc
push hl
farcall LoadEnemyMon
- farcall SendPkmnIntoBox
+ farcall SendMonIntoBox
farcall SetBoxMonCaughtData
pop hl
pop bc
diff --git a/sram.asm b/sram.asm
index 66c8af2c4..a7b9167c3 100644
--- a/sram.asm
+++ b/sram.asm
@@ -208,14 +208,14 @@ sBattleTowerSaveFileFlags:: db
sBattleTowerReward:: db
; team of previous trainer
-sBTPkmnOfTrainers:: ; 0xbe51
-sBTPkmnPrevTrainer1:: db
-sBTPkmnPrevTrainer2:: db
-sBTPkmnPrevTrainer3:: db
+sBTMonOfTrainers:: ; 0xbe51
+sBTMonPrevTrainer1:: db
+sBTMonPrevTrainer2:: db
+sBTMonPrevTrainer3:: db
; team of preprevious trainer
-sBTPkmnPrevPrevTrainer1:: db
-sBTPkmnPrevPrevTrainer2:: db
-sBTPkmnPrevPrevTrainer3:: db
+sBTMonPrevPrevTrainer1:: db
+sBTMonPrevPrevTrainer2:: db
+sBTMonPrevPrevTrainer3:: db
SECTION "Boxes 1-7", SRAM, BANK [2]
diff --git a/wram.asm b/wram.asm
index 1a14a0171..c26078f04 100644
--- a/wram.asm
+++ b/wram.asm
@@ -1641,7 +1641,7 @@ wCurrentRadioLine:: db
wNextRadioLine:: db
wRadioTextDelay:: db
wNumRadioLinesPrinted:: db
-wOaksPkmnTalkSegmentCounter:: db
+wOaksPKMNTalkSegmentCounter:: db
ds 5
wRadioText:: ds 2 * SCREEN_WIDTH
wRadioTextEnd::
diff --git a/engine/battle/core.asm b/engine/battle/core.asm
index 0fe77df40..df9d4cbc5 100644
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -47,7 +47,7 @@ DoBattle: ; 3c000
.player_2
call LoadTileMapToTempTileMap
- call CheckPlayerPartyForFitPkmn
+ call CheckPlayerPartyForFitMon
ld a, d
and a
jp z, LostBattle
@@ -86,7 +86,7 @@ DoBattle: ; 3c000
call ResetBattleParticipants
call InitBattleMon
call ResetPlayerStatLevels
- call SendOutPkmnText
+ call SendOutMonText
call NewBattleMonStatus
call BreakAttraction
call SendOutPlayerMon
@@ -1697,7 +1697,7 @@ HandleScreens: ; 3cb36
res SCREENS_LIGHT_SCREEN, [hl]
push hl
push de
- ld hl, BattleText_PkmnLightScreenFell
+ ld hl, BattleText_MonsLightScreenFell
call StdBattleTextBox
pop de
pop hl
@@ -1711,7 +1711,7 @@ HandleScreens: ; 3cb36
ld [de], a
ret nz
res SCREENS_REFLECT, [hl]
- ld hl, BattleText_PkmnReflectFaded
+ ld hl, BattleText_MonsReflectFaded
jp StdBattleTextBox
; 3cb9e
@@ -1822,7 +1822,7 @@ SubtractHPFromTarget: ; 3cc39
; 3cc3f
SubtractHPFromUser: ; 3cc3f
-; Subtract HP from Pkmn
+; Subtract HP from mon
call SubtractHP
jp UpdateHPBarBattleHuds
; 3cc45
@@ -2054,7 +2054,7 @@ HandleEnemyMonFaint: ; 3cd55
xor a
ld [wWhichMonFaintedFirst], a
call UpdateBattleStateAndExperienceAfterEnemyFaint
- call CheckPlayerPartyForFitPkmn
+ call CheckPlayerPartyForFitMon
ld a, d
and a
jp z, LostBattle
@@ -2186,7 +2186,7 @@ UpdateBattleStateAndExperienceAfterEnemyFaint: ; 3ce01
call PlayerMonFaintHappinessMod
.player_mon_did_not_faint
- call CheckPlayerPartyForFitPkmn
+ call CheckPlayerPartyForFitMon
ld a, d
and a
ret z
@@ -2308,7 +2308,7 @@ FaintYourPokemon: ; 3cef1
hlcoord 9, 7
lb bc, 5, 11
call ClearBox
- ld hl, BattleText_PkmnFainted
+ ld hl, BattleText_MonFainted
jp StdBattleTextBox
; 3cf14
@@ -2322,7 +2322,7 @@ FaintEnemyPokemon: ; 3cf14
hlcoord 1, 0
lb bc, 4, 10
call ClearBox
- ld hl, BattleText_EnemyPkmnFainted
+ ld hl, BattleText_EnemyMonFainted
jp StdBattleTextBox
; 3cf35
@@ -2670,7 +2670,7 @@ HandlePlayerMonFaint: ; 3d14e
ld a, $1
ld [wWhichMonFaintedFirst], a
call PlayerMonFaintHappinessMod
- call CheckPlayerPartyForFitPkmn
+ call CheckPlayerPartyForFitMon
ld a, d
and a
jp z, LostBattle
@@ -2829,7 +2829,7 @@ ForcePlayerMonChoice: ; 3d227
call CloseWindow
call GetMemSGBLayout
call SetPalettes
- call SendOutPkmnText
+ call SendOutMonText
call NewBattleMonStatus
call BreakAttraction
call SendOutPlayerMon
@@ -2851,7 +2851,7 @@ PlayerPartyMonEntrance: ; 3d2b3
call AddBattleParticipant
call InitBattleMon
call ResetPlayerStatLevels
- call SendOutPkmnText
+ call SendOutMonText
call NewBattleMonStatus
call BreakAttraction
call SendOutPlayerMon
@@ -2934,7 +2934,7 @@ SwitchMonAlreadyOut: ; 3d34f
cp [hl]
jr nz, .notout
- ld hl, BattleText_PkmnIsAlreadyOut
+ ld hl, BattleText_MonIsAlreadyOut
call StdBattleTextBox
scf
ret
@@ -3197,11 +3197,11 @@ ForceEnemySwitch: ; 3d4c3
ld a, [wEnemySwitchMonIndex]
dec a
ld b, a
- call LoadEnemyPkmnToSwitchTo
+ call LoadEnemyMonToSwitchTo
call ClearEnemyMonBox
call NewEnemyMonStatus
call ResetEnemyStatLevels
- call Function_SetEnemyPkmnAndSendOutAnimation
+ call Function_SetEnemyMonAndSendOutAnimation
call BreakAttraction
call ResetBattleParticipants
ret
@@ -3214,15 +3214,15 @@ EnemySwitch: ; 3d4e1
call ResetEnemyBattleVars
call CheckWhetherSwitchmonIsPredetermined
jr c, .skip
- call FindPkmnInOTPartyToSwitchIntoBattle
+ call FindMonInOTPartyToSwitchIntoBattle
.skip
- ; 'b' contains the PartyNr of the Pkmn the AI will switch to
- call LoadEnemyPkmnToSwitchTo
+ ; 'b' contains the PartyNr of the mon the AI will switch to
+ call LoadEnemyMonToSwitchTo
call OfferSwitch
push af
call ClearEnemyMonBox
call Function_BattleTextEnemySentOut
- call Function_SetEnemyPkmnAndSendOutAnimation
+ call Function_SetEnemyMonAndSendOutAnimation
pop af
ret c
; If we're here, then we're switching too
@@ -3240,15 +3240,15 @@ EnemySwitch_SetMode: ; 3d517
call ResetEnemyBattleVars
call CheckWhetherSwitchmonIsPredetermined
jr c, .skip
- call FindPkmnInOTPartyToSwitchIntoBattle
+ call FindMonInOTPartyToSwitchIntoBattle
.skip
- ; 'b' contains the PartyNr of the Pkmn the AI will switch to
- call LoadEnemyPkmnToSwitchTo
+ ; 'b' contains the PartyNr of the mon the AI will switch to
+ call LoadEnemyMonToSwitchTo
ld a, 1
ld [wEnemyIsSwitching], a
call ClearEnemyMonBox
call Function_BattleTextEnemySentOut
- jp Function_SetEnemyPkmnAndSendOutAnimation
+ jp Function_SetEnemyMonAndSendOutAnimation
; 3d533
CheckWhetherSwitchmonIsPredetermined: ; 3d533
@@ -3319,7 +3319,7 @@ AddBattleParticipant: ; 3d581
predef_jump SmallFarFlagAction
; 3d599
-FindPkmnInOTPartyToSwitchIntoBattle: ; 3d599
+FindMonInOTPartyToSwitchIntoBattle: ; 3d599
ld b, $ff
ld a, $1
ld [wBuffer1], a
@@ -3347,7 +3347,7 @@ FindPkmnInOTPartyToSwitchIntoBattle: ; 3d599
pop bc
jr z, .discourage
call LookUpTheEffectivenessOfEveryMove
- call IsThePlayerPkmnTypesEffectiveAgainstOTPkmn
+ call IsThePlayerMonTypesEffectiveAgainstOTMon
jr .loop
.discourage
@@ -3394,9 +3394,9 @@ LookUpTheEffectivenessOfEveryMove: ; 3d5d7
ret
; 3d618
-IsThePlayerPkmnTypesEffectiveAgainstOTPkmn: ; 3d618
-; Calculates the effectiveness of the types of the PlayerPkmn
-; against the OTPkmn
+IsThePlayerMonTypesEffectiveAgainstOTMon: ; 3d618
+; Calculates the effectiveness of the types of the PlayerMon
+; against the OTMon
push bc
ld hl, wOTPartyCount
ld a, b
@@ -3508,8 +3508,8 @@ ScoreMonTypeMatchups: ; 3d672
ret
; 3d6ca
-LoadEnemyPkmnToSwitchTo: ; 3d6ca
- ; 'b' contains the PartyNr of the Pkmn the AI will switch to
+LoadEnemyMonToSwitchTo: ; 3d6ca
+ ; 'b' contains the PartyNr of the mon the AI will switch to
ld a, b
ld [wCurPartyMon], a
ld hl, wOTPartyMon1Level
@@ -3581,7 +3581,7 @@ OfferSwitch: ; 3d74b
ld a, [wCurPartyMon]
push af
callfar Battle_GetTrainerName
- ld hl, BattleText_EnemyIsAboutToUseWillPlayerChangePkmn
+ ld hl, BattleText_EnemyIsAboutToUseWillPlayerChangeMon
call StdBattleTextBox
lb bc, 1, 7
call PlaceYesNoBox
@@ -3637,14 +3637,14 @@ Function_BattleTextEnemySentOut: ; 3d7b8
jp WaitBGMap
; 3d7c7
-Function_SetEnemyPkmnAndSendOutAnimation: ; 3d7c7
+Function_SetEnemyMonAndSendOutAnimation: ; 3d7c7
ld a, [wTempEnemyMonSpecies]
ld [wCurPartySpecies], a
ld [wCurSpecies], a
call GetBaseData
ld a, OTPARTYMON
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
call GetEnemyMonFrontpic
xor a
@@ -3721,8 +3721,8 @@ ResetEnemyStatLevels: ; 3d867
ret
; 3d873
-CheckPlayerPartyForFitPkmn: ; 3d873
-; Has the player any Pkmn in his Party that can fight?
+CheckPlayerPartyForFitMon: ; 3d873
+; Has the player any mon in his Party that can fight?
ld a, [wPartyCount]
ld e, a
xor a
@@ -4308,7 +4308,7 @@ PursuitSwitch: ; 3dc5b
ld b, RESET_FLAG
predef SmallFarFlagAction
call PlayerMonFaintedAnimation
- ld hl, BattleText_PkmnFainted
+ ld hl, BattleText_MonFainted
jr .done_fainted
.check_enemy_fainted
@@ -4324,7 +4324,7 @@ PursuitSwitch: ; 3dc5b
call PlaySFX
call WaitSFX
call EnemyMonFaintedAnimation
- ld hl, BattleText_EnemyPkmnFainted
+ ld hl, BattleText_EnemyMonFainted
.done_fainted
call StdBattleTextBox
@@ -5306,7 +5306,7 @@ TryPlayerSwitch: ; 3e358
ld a, [wCurPartyMon]
cp d
jr nz, .check_trapped
- ld hl, BattleText_PkmnIsAlreadyOut
+ ld hl, BattleText_MonIsAlreadyOut
call StdBattleTextBox
jp BattleMenuPKMN_Loop
@@ -5319,7 +5319,7 @@ TryPlayerSwitch: ; 3e358
jr z, .try_switch
.trapped
- ld hl, BattleText_PkmnCantBeRecalled
+ ld hl, BattleText_MonCantBeRecalled
call StdBattleTextBox
jp BattleMenuPKMN_Loop
@@ -5396,7 +5396,7 @@ EnemyMonEntrance: ; 3e3ff
; 3e40b
BattleMonEntrance: ; 3e40b
- call WithdrawPkmnText
+ call WithdrawMonText
ld c, 50
call DelayFrames
@@ -5419,7 +5419,7 @@ BattleMonEntrance: ; 3e40b
call AddBattleParticipant
call InitBattleMon
call ResetPlayerStatLevels
- call SendOutPkmnText
+ call SendOutMonText
call NewBattleMonStatus
call BreakAttraction
call SendOutPlayerMon
@@ -5938,7 +5938,7 @@ CheckPlayerHasUsableMoves: ; 3e786
ret nz
.force_struggle
- ld hl, BattleText_PkmnHasNoMovesLeft
+ ld hl, BattleText_MonHasNoMovesLeft
call StdBattleTextBox
ld c, 60
call DelayFrames
@@ -6408,7 +6408,7 @@ LoadEnemyMon: ; 3e8eb
ld de, wEnemyMonMaxHP
ld b, FALSE
ld hl, wEnemyMonDVs - (MON_DVS - MON_STAT_EXP + 1) ; wLinkBattleRNs + 7 ; ?
- predef CalcPkmnStats
+ predef CalcMonStats
; If we're in a trainer battle,
; get the rest of the parameters from the party struct
@@ -7350,7 +7350,7 @@ GiveExperiencePoints: ; 3ee3b
ld a, [wCurPartyMon]
ld hl, wPartyMonNicknames
call GetNick
- ld hl, Text_PkmnGainedExpPoint
+ ld hl, Text_MonGainedExpPoint
call BattleTextBox
ld a, [wStringBuffer2 + 1]
ld [hQuotient + 2], a
@@ -7419,7 +7419,7 @@ GiveExperiencePoints: ; 3ee3b
.not_max_exp
xor a ; PARTYMON
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
callfar CalcLevel
pop bc
ld hl, MON_LEVEL
@@ -7456,7 +7456,7 @@ GiveExperiencePoints: ; 3ee3b
add hl, bc
push bc
ld b, TRUE
- predef CalcPkmnStats
+ predef CalcMonStats
pop bc
pop de
ld hl, MON_MAXHP + 1
@@ -7532,7 +7532,7 @@ GiveExperiencePoints: ; 3ee3b
.skip_animation2
xor a ; PARTYMON
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
hlcoord 9, 0
ld b, $a
ld c, $9
@@ -7648,7 +7648,7 @@ BoostExp: ; 3f106
ret
; 3f11b
-Text_PkmnGainedExpPoint: ; 3f11b
+Text_MonGainedExpPoint: ; 3f11b
text_jump Text_Gained
start_asm
ld hl, TextJump_StringBuffer2ExpPoints
@@ -7692,7 +7692,7 @@ AnimateExpBar: ; 3f136
ld [wd002], a
xor a ; PARTYMON
ld [wMonType], a
- predef CopyPkmnToTempMon
+ predef CopyMonToTempMon
ld a, [wTempMonLevel]
ld b, a
ld e, a
@@ -7856,23 +7856,23 @@ AnimateExpBar: ; 3f136
ld [hBGMapMode], a
ret
-SendOutPkmnText: ; 3f26d
+SendOutMonText: ; 3f26d
ld a, [wLinkMode]
and a
jr z, .not_linked
- ld hl, JumpText_GoPkmn ; If we're in a LinkBattle print just "Go <PlayerMon>"
+ ld hl, JumpText_GoMon ; If we're in a LinkBattle print just "Go <PlayerMon>"
ld a, [wBattleHasJustStarted] ; unless this (unidentified) variable is set
and a
jr nz, .skip_to_textbox
.not_linked
-; Depending on the HP of the enemy Pkmn, the game prints a different text
+; Depending on the HP of the enemy mon, the game prints a different text
ld hl, wEnemyMonHP
ld a, [hli]
or [hl]
- ld hl, JumpText_GoPkmn
+ ld hl, JumpText_GoMon
jr z, .skip_to_textbox
; compute enemy helth remaining as a percentage
@@ -7901,43 +7901,43 @@ SendOutPkmnText: ; 3f26d
call Divide
ld a, [hQuotient + 2]
- ld hl, JumpText_GoPkmn
+ ld hl, JumpText_GoMon
cp 70
jr nc, .skip_to_textbox
- ld hl, JumpText_DoItPkmn
+ ld hl, JumpText_DoItMon
cp 40
jr nc, .skip_to_textbox
- ld hl, JumpText_GoForItPkmn
+ ld hl, JumpText_GoForItMon
cp 10
jr nc, .skip_to_textbox
- ld hl, JumpText_YourFoesWeakGetmPkmn
+ ld hl, JumpText_YourFoesWeakGetmMon
.skip_to_textbox
jp BattleTextBox
; 3f2d1
-JumpText_GoPkmn: ; 3f2d1
- text_jump Text_GoPkmn
+JumpText_GoMon: ; 3f2d1
+ text_jump Text_GoMon
start_asm
jr Function_TextJump_BattleMonNick01
; 3f2d6
-JumpText_DoItPkmn: ; 3f2d8
- text_jump Text_DoItPkmn
+JumpText_DoItMon: ; 3f2d8
+ text_jump Text_DoItMon
start_asm
jr Function_TextJump_BattleMonNick01
; 3f2dd
-JumpText_GoForItPkmn: ; 3f2df
- text_jump Text_GoForItPkmn
+JumpText_GoForItMon: ; 3f2df
+ text_jump Text_GoForItMon
start_asm
jr Function_TextJump_BattleMonNick01
; 3f2e4
-JumpText_YourFoesWeakGetmPkmn: ; 3f2e6
- text_jump Text_YourFoesWeakGetmPkmn
+JumpText_YourFoesWeakGetmMon: ; 3f2e6
+ text_jump Text_YourFoesWeakGetmMon
start_asm
Function_TextJump_BattleMonNick01: ; 3f2eb
ld hl, TextJump_BattleMonNick01
@@ -7949,14 +7949,14 @@ TextJump_BattleMonNick01: ; 3f2ef
db "@"
; 3f2f4
-WithdrawPkmnText: ; 3f2f4
- ld hl, .WithdrawPkmnText
+WithdrawMonText: ; 3f2f4
+ ld hl, .WithdrawMonText
jp BattleTextBox
-.WithdrawPkmnText:
+.WithdrawMonText:
text_jump Text_BattleMonNickComma
start_asm
-; Print text to withdraw Pkmn
+; Print text to withdraw mon
; depending on HP the message is different
push de
push bc
@@ -8037,7 +8037,7 @@ Unreferenced_HandleSafariAngerEatingStatus:
and a
jr z, .angry
dec [hl]
- ld hl, BattleText_WildPkmnIsEating
+ ld hl, BattleText_WildMonIsEating
jr .finish
.angry
@@ -8046,7 +8046,7 @@ Unreferenced_HandleSafariAngerEatingStatus:
and a
ret z
dec [hl]
- ld hl, BattleText_WildPkmnIsAngry
+ ld hl, BattleText_WildMonIsAngry
jr nz, .finish
push hl
ld a, [wEnemyMonSpecies]
diff --git a/engine/events/battle_tower/battle_tower.asm b/engine/events/battle_tower/battle_tower.asm
index 4b4494925..5c430d39b 100755
--- a/engine/events/battle_tower/battle_tower.asm
+++ b/engine/events/battle_tower/battle_tower.asm
@@ -95,7 +95,7 @@ Function170139: ; 170139
ld [wMisc], a
ld a, l
ld [wMisc + 1], a
- ld hl, wBT_OTTempPkmn1DVs
+ ld hl, wBT_OTTempMon1DVs
ld a, [wPlayerID]
ld [hli], a
ld a, [wPlayerID + 1]
@@ -112,7 +112,7 @@ Function170139: ; 170139
ld bc, wPlayerID
ld de, wPlayerGender
farcall GetMobileOTTrainerClass
- ld de, wBT_OTTempPkmn1CaughtGender
+ ld de, wBT_OTTempMon1CaughtGender
ld a, c
ld [de], a
inc de
@@ -279,59 +279,59 @@ RunBattleTowerTrainer: ; 17024d
ReadBTTrainerParty: ; 1702b7
; Initialise the BattleTower-Trainer and his Pkmn
call CopyBTTrainer_FromBT_OT_TowBT_OTTemp
; Check the nicknames for illegal characters, and replace bad nicknames
; with their species names.
- ld de, wBT_OTTempPkmn1Name ; $c643
+ ld de, wBT_OTTempMon1Name ; $c643
ld c, MON_NAME_LENGTH
farcall CheckStringForErrors
jr nc, .skip_mon_1
- ld a, [wBT_OTTempPkmn1]
+ ld a, [wBT_OTTempMon1]
ld [wNamedObjectIndexBuffer], a
call GetPokemonName
ld l, e
ld h, d
- ld de, wBT_OTTempPkmn1Name ; $c643
+ ld de, wBT_OTTempMon1Name ; $c643
ld bc, MON_NAME_LENGTH
call CopyBytes
.skip_mon_1
- ld de, wBT_OTTempPkmn2Name ; $c67e
+ ld de, wBT_OTTempMon2Name ; $c67e
ld c, MON_NAME_LENGTH
farcall CheckStringForErrors
jr nc, .skip_mon_2
- ld a, [wBT_OTTempPkmn2] ; [$c64e]
+ ld a, [wBT_OTTempMon2] ; [$c64e]
ld [wNamedObjectIndexBuffer], a
call GetPokemonName
ld l, e
ld h, d
- ld de, wBT_OTTempPkmn2Name ; $c67e
+ ld de, wBT_OTTempMon2Name ; $c67e
ld bc, MON_NAME_LENGTH
call CopyBytes
.skip_mon_2
- ld de, wBT_OTTempPkmn3Name ; $c686 + 51 = $c6b9
+ ld de, wBT_OTTempMon3Name ; $c686 + 51 = $c6b9
ld c, MON_NAME_LENGTH
farcall CheckStringForErrors
jr nc, .skip_mon_3
- ld a, [wBT_OTTempPkmn3] ; [$c689]
+ ld a, [wBT_OTTempMon3] ; [$c689]
ld [wNamedObjectIndexBuffer], a
call GetPokemonName
ld l, e
ld h, d
- ld de, wBT_OTTempPkmn3Name ; $c686 + 51 = $c6b9
+ ld de, wBT_OTTempMon3Name ; $c686 + 51 = $c6b9
ld bc, MON_NAME_LENGTH
call CopyBytes
.skip_mon_3
; Add the terminator character to each of these names
ld a, "@"
- ld [wBT_OTTempPkmn1NameEnd - 1], a ; $c64d
- ld [wBT_OTTempPkmn2NameEnd - 1], a ; $c688
- ld [wBT_OTTempPkmn3NameEnd - 1], a ; $c68a + 57 = $c6c3
+ ld [wBT_OTTempMon1NameEnd - 1], a ; $c64d
+ ld [wBT_OTTempMon2NameEnd - 1], a ; $c688
+ ld [wBT_OTTempMon3NameEnd - 1], a ; $c68a + 57 = $c6c3
; Fix errors in the movesets
call CheckBTMonMovesForErrors
; Repair the trainer name if needed, then copy it to wOTPlayerName
@@ -360,7 +360,7 @@ ReadBTTrainerParty: ; 1702b7
ld a, HIGH(wOTPartyMonNicknames)
ld [wBGMapBuffer + 1], a
; Copy Pkmn into Memory from the address in hl
ld de, wOTPartyMon1Species
ld bc, wOTPartyCount
ld a, BATTLETOWER_PARTY_LENGTH
@@ -398,7 +398,7 @@ ReadBTTrainerParty: ; 1702b7
ValidateBTParty: ; 170394
; Check for and fix errors in party data
- ld hl, wBT_OTTempPkmn1Species
+ ld hl, wBT_OTTempMon1Species
ld d, BATTLETOWER_PARTY_LENGTH
.pkmn_loop
push de
@@ -484,7 +484,7 @@ endr
ld hl, MON_STAT_EXP - 1
add hl, bc
ld b, $1
- predef CalcPkmnStats
+ predef CalcMonStats
pop de
pop hl
dec de
@@ -279,59 +279,59 @@ RunBattleTowerTrainer: ; 17024d
ReadBTTrainerParty: ; 1702b7
-; Initialise the BattleTower-Trainer and his Pkmn
+; Initialise the BattleTower-Trainer and his mon
call CopyBTTrainer_FromBT_OT_TowBT_OTTemp
; Check the nicknames for illegal characters, and replace bad nicknames
@@ -360,7 +360,7 @@ ReadBTTrainerParty: ; 1702b7
ld a, HIGH(wOTPartyMonNicknames)
ld [wBGMapBuffer + 1], a
- ; Copy Pkmn into Memory from the address in hl
+ ; Copy mon into Memory from the address in hl
ld de, wOTPartyMon1Species
ld bc, wOTPartyCount
diff --git a/engine/events/battle_tower/load_trainer.asm b/engine/events/battle_tower/load_trainer.asm
index bfb5cf885..f3db16293 100644
--- a/engine/events/battle_tower/load_trainer.asm
+++ b/engine/events/battle_tower/load_trainer.asm
@@ -12,9 +12,9 @@ Function_LoadOpponentTrainerAndPokemons: ; 1f8000
; Write $ff into the Item-Slots
ld a, $ff
- ld [wBT_OTPkmn1Item], a
- ld [wBT_OTPkmn2Item], a
- ld [wBT_OTPkmn3Item], a
+ ld [wBT_OTMon1Item], a
+ ld [wBT_OTMon2Item], a
+ ld [wBT_OTMon3Item], a
; Set wBT_OTTrainer as start address to write the following data to
ld de, wBT_OTTrainer
@@ -32,8 +32,8 @@ if DEF(_CRYSTAL11)
else
; Crystal 1.0 used the wrong constant here, so only the first 21
; trainers in BattleTowerTrainers can be sampled.
- maskbits BATTLETOWER_NUM_UNIQUE_PKMN
- cp BATTLETOWER_NUM_UNIQUE_PKMN
+ maskbits BATTLETOWER_NUM_UNIQUE_MON
+ cp BATTLETOWER_NUM_UNIQUE_MON
endc
jr nc, .resample
ld b, a
@@ -68,7 +68,7 @@ endc
ld bc, NAME_LENGTH
call CopyBytes
- call Function_LoadRandomBattleTowerPkmn
+ call Function_LoadRandomBattleTowerMon
pop af
ld hl, BattleTowerTrainerData
@@ -92,15 +92,15 @@ endc
ret
-Function_LoadRandomBattleTowerPkmn: ; 1f8081
+Function_LoadRandomBattleTowerMon: ; 1f8081
ld c, BATTLETOWER_PARTY_LENGTH
.loop
push bc
- ld a, BANK(sBTPkmnPrevTrainer1)
+ ld a, BANK(sBTMonPrevTrainer1)
call GetSRAMBank
-.FindARandomBattleTowerPkmn:
- ; From Which LevelGroup are the Pkmn loaded
+.FindARandomBattleTowerMon:
+ ; From Which LevelGroup are the mon loaded
; a = 1..10
ld a, [wBTChoiceOfLvlGroup]
dec a
@@ -115,12 +115,12 @@ Function_LoadRandomBattleTowerPkmn: ; 1f8081
ld a, [hRandomAdd]
add b
ld b, a
- maskbits BATTLETOWER_NUM_UNIQUE_PKMN
- cp BATTLETOWER_NUM_UNIQUE_PKMN
+ maskbits BATTLETOWER_NUM_UNIQUE_MON
+ cp BATTLETOWER_NUM_UNIQUE_MON
jr nc, .resample
; in register 'a' is the chosen Pkmn of the LevelGroup
; Check if Pkmn was already loaded before
; Check current and the 2 previous teams
; includes check if item is double at the current team
ld bc, PARTYMON_STRUCT_LENGTH + MON_NAME_LENGTH
@@ -129,42 +129,42 @@ Function_LoadRandomBattleTowerPkmn: ; 1f8081
ld b, a
ld a, [hld]
ld c, a
- ld a, [wBT_OTPkmn1]
+ ld a, [wBT_OTMon1]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [wBT_OTPkmn1Item]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [wBT_OTMon1Item]
cp c
- jr z, .FindARandomBattleTowerPkmn
- ld a, [wBT_OTPkmn2]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [wBT_OTMon2]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [wBT_OTPkmn2Item]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [wBT_OTMon2Item]
cp c
- jr z, .FindARandomBattleTowerPkmn
- ld a, [wBT_OTPkmn3]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [wBT_OTMon3]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [wBT_OTPkmn3Item]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [wBT_OTMon3Item]
cp c
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevTrainer1]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevTrainer1]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevTrainer2]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevTrainer2]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevTrainer3]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevTrainer3]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevPrevTrainer1]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevPrevTrainer1]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevPrevTrainer2]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevPrevTrainer2]
cp b
- jr z, .FindARandomBattleTowerPkmn
- ld a, [sBTPkmnPrevPrevTrainer3]
+ jr z, .FindARandomBattleTowerMon
+ ld a, [sBTMonPrevPrevTrainer3]
cp b
- jr z, .FindARandomBattleTowerPkmn
+ jr z, .FindARandomBattleTowerMon
ld bc, PARTYMON_STRUCT_LENGTH + MON_NAME_LENGTH
call CopyBytes
@@ -193,18 +193,18 @@ Function_LoadRandomBattleTowerPkmn: ; 1f8081
dec c
jp nz, .loop
- ld a, [sBTPkmnPrevTrainer1]
- ld [sBTPkmnPrevPrevTrainer1], a
- ld a, [sBTPkmnPrevTrainer2]
- ld [sBTPkmnPrevPrevTrainer2], a
- ld a, [sBTPkmnPrevTrainer3]
- ld [sBTPkmnPrevPrevTrainer3], a
- ld a, [wBT_OTPkmn1]
- ld [sBTPkmnPrevTrainer1], a
- ld a, [wBT_OTPkmn2]
- ld [sBTPkmnPrevTrainer2], a
- ld a, [wBT_OTPkmn3]
- ld [sBTPkmnPrevTrainer3], a
+ ld a, [sBTMonPrevTrainer1]
+ ld [sBTMonPrevPrevTrainer1], a
+ ld a, [sBTMonPrevTrainer2]
+ ld [sBTMonPrevPrevTrainer2], a
+ ld a, [sBTMonPrevTrainer3]
+ ld [sBTMonPrevPrevTrainer3], a
+ ld a, [wBT_OTMon1]
+ ld [sBTMonPrevTrainer1], a
+ ld a, [wBT_OTMon2]
+ ld [sBTMonPrevTrainer2], a
+ ld a, [wBT_OTMon3]
+ ld [sBTMonPrevTrainer3], a
call CloseSRAM
ret
; 1f814e
@@ -115,12 +115,12 @@ Function_LoadRandomBattleTowerPkmn: ; 1f8081
jr nc, .resample
- ; in register 'a' is the chosen Pkmn of the LevelGroup
+ ; in register 'a' is the chosen mon of the LevelGroup
- ; Check if Pkmn was already loaded before
+ ; Check if mon was already loaded before
; Check current and the 2 previous teams
; includes check if item is double at the current team
diff --git a/engine/radio.asm b/engine/radio.asm
index e6ee257ee..f0326f167 100644
--- a/engine/radio.asm
+++ b/engine/radio.asm
@@ -29,7 +29,7 @@ PlayRadioShow:
RadioJumptable:
; entries correspond to constants/radio_constants.asm
- dw OaksPkmnTalk1 ; $00
+ dw OaksPKMNTalk1 ; $00
dw PokedexShow1 ; $01
dw BenMonMusic1 ; $02
dw LuckyNumberShow1 ; $03
@@ -40,15 +40,15 @@ RadioJumptable:
dw PokeFluteRadio ; $08
dw UnownRadio ; $09
dw EvolutionRadio ; $0a
-; OaksPkmnTalk
- dw OaksPkmnTalk2 ; $0b
- dw OaksPkmnTalk3 ; $0c
- dw OaksPkmnTalk4 ; $0d
- dw OaksPkmnTalk5 ; $0e
- dw OaksPkmnTalk6 ; $0f
- dw OaksPkmnTalk7 ; $10
- dw OaksPkmnTalk8 ; $11
- dw OaksPkmnTalk9 ; $12
+; OaksPKMNTalk
+ dw OaksPKMNTalk2 ; $0b
+ dw OaksPKMNTalk3 ; $0c
+ dw OaksPKMNTalk4 ; $0d
+ dw OaksPKMNTalk5 ; $0e
+ dw OaksPKMNTalk6 ; $0f
+ dw OaksPKMNTalk7 ; $10
+ dw OaksPKMNTalk8 ; $11
+ dw OaksPKMNTalk9 ; $12
dw PokedexShow2 ; $13
dw PokedexShow3 ; $14
dw PokedexShow4 ; $15
@@ -94,11 +94,11 @@ RadioJumptable:
dw RocketRadio9 ; $39
dw RocketRadio10 ; $3a
; More Pokemon Channel stuff
- dw OaksPkmnTalk10 ; $3b
- dw OaksPkmnTalk11 ; $3c
- dw OaksPkmnTalk12 ; $3d
- dw OaksPkmnTalk13 ; $3e
- dw OaksPkmnTalk14 ; $3f
+ dw OaksPKMNTalk10 ; $3b
+ dw OaksPKMNTalk11 ; $3c
+ dw OaksPKMNTalk12 ; $3d
+ dw OaksPKMNTalk13 ; $3e
+ dw OaksPKMNTalk14 ; $3f
; Buenas Password
dw BuenasPassword2 ; $40
dw BuenasPassword3 ; $41
@@ -182,33 +182,33 @@ RadioScroll:
call nz, CopyBottomLineToTopLine
jp ClearBottomLine
-OaksPkmnTalk1:
+OaksPKMNTalk1:
ld a, 5
- ld [wOaksPkmnTalkSegmentCounter], a
+ ld [wOaksPKMNTalkSegmentCounter], a
call StartRadioStation
ld hl, OPT_IntroText1
ld a, OAKS_POKEMON_TALK_2
jp NextRadioLine
-OaksPkmnTalk2:
+OaksPKMNTalk2:
ld hl, OPT_IntroText2
ld a, OAKS_POKEMON_TALK_3
jp NextRadioLine
-OaksPkmnTalk3:
+OaksPKMNTalk3:
ld hl, OPT_IntroText3
ld a, OAKS_POKEMON_TALK_4
jp NextRadioLine
-OaksPkmnTalk4:
+OaksPKMNTalk4:
; Choose a random route, and a random Pokemon from that route.
.sample
call Random
and %11111
- cp (OaksPkmnTalkRoutesEnd - OaksPkmnTalkRoutes) / 2
+ cp (OaksPKMNTalkRoutesEnd - OaksPKMNTalkRoutes) / 2
jr nc, .sample
; We now have a number between 0 and 14.
- ld hl, OaksPkmnTalkRoutes
+ ld hl, OaksPKMNTalkRoutes
ld c, a
ld b, 0
add hl, bc
@@ -294,12 +294,12 @@ endr
INCLUDE "data/radio/oaks_pkmn_talk_routes.asm"
-OaksPkmnTalk5:
+OaksPKMNTalk5:
ld hl, OPT_OakText2
ld a, OAKS_POKEMON_TALK_6
jp NextRadioLine
-OaksPkmnTalk6:
+OaksPKMNTalk6:
ld hl, OPT_OakText3
ld a, OAKS_POKEMON_TALK_7
jp NextRadioLine
@@ -334,7 +334,7 @@ OPT_OakText3:
text_jump _OPT_OakText3
db "@"
-OaksPkmnTalk7:
+OaksPKMNTalk7:
ld a, [wCurPartySpecies]
ld [wNamedObjectIndexBuffer], a
call GetPokemonName
@@ -347,11 +347,11 @@ OPT_MaryText1:
text_jump _OPT_MaryText1
db "@"
-OaksPkmnTalk8:
+OaksPKMNTalk8:
; 0-15 are all valid indexes into .Adverbs,
; so no need for a retry loop
call Random
- maskbits NUM_OAKS_MON_TALK_ADVERBS
+ maskbits NUM_OAKS_POKEMON_TALK_ADVERBS
ld e, a
ld d, 0
ld hl, .Adverbs
@@ -364,7 +364,7 @@ OaksPkmnTalk8:
jp NextRadioLine
.Adverbs:
; there are NUM_OAKS_MON_TALK_ADVERBS entries
dw .sweetadorably
dw .wigglyslickly
dw .aptlynamed
@@ -462,11 +462,11 @@ OaksPkmnTalk8:
text_jump OPT_HeartMeltingly
db "@"
-OaksPkmnTalk9:
+OaksPKMNTalk9:
; 0-15 are all valid indexes into .Adjectives,
; so no need for a retry loop
call Random
- maskbits NUM_OAKS_MON_TALK_ADJECTIVES
+ maskbits NUM_OAKS_POKEMON_TALK_ADJECTIVES
ld e, a
ld d, 0
ld hl, .Adjectives
@@ -475,19 +475,19 @@ OaksPkmnTalk9:
ld a, [hli]
ld h, [hl]
ld l, a
- ld a, [wOaksPkmnTalkSegmentCounter]
+ ld a, [wOaksPKMNTalkSegmentCounter]
dec a
- ld [wOaksPkmnTalkSegmentCounter], a
+ ld [wOaksPKMNTalkSegmentCounter], a
ld a, OAKS_POKEMON_TALK_4
jr nz, .ok
ld a, 5
- ld [wOaksPkmnTalkSegmentCounter], a
+ ld [wOaksPKMNTalkSegmentCounter], a
ld a, OAKS_POKEMON_TALK_10
.ok
jp NextRadioLine
.Adjectives:
; there are NUM_OAKS_MON_TALK_ADJECTIVES entries
dw .cute
dw .weird
dw .pleasant
@@ -585,7 +585,7 @@ OaksPkmnTalk9:
text_jump OPT_Speedy
db "@"
-OaksPkmnTalk10:
+OaksPKMNTalk10:
farcall RadioMusicRestartPokemonChannel
ld hl, OPT_RestartText
call PrintText
@@ -606,7 +606,7 @@ OPT_PokemonChannelText:
OPT_RestartText:
db "@"
-OaksPkmnTalk11:
+OaksPKMNTalk11:
ld hl, wRadioTextDelay
dec [hl]
ret nz
@@ -618,7 +618,7 @@ OaksPkmnTalk11:
.pokemon_string
db "#MON@"
-OaksPkmnTalk12:
+OaksPKMNTalk12:
ld hl, wRadioTextDelay
dec [hl]
ret nz
@@ -630,7 +630,7 @@ OaksPkmnTalk12:
.pokemon_channel_string
db "#MON Channel@"
-OaksPkmnTalk13:
+OaksPKMNTalk13:
ld hl, wRadioTextDelay
dec [hl]
ret nz
@@ -642,7 +642,7 @@ OaksPkmnTalk13:
.terminator
db "@"
-OaksPkmnTalk14:
+OaksPKMNTalk14:
ld hl, wRadioTextDelay
dec [hl]
ret nz
@@ -364,7 +364,7 @@ OaksPkmnTalk8:
jp NextRadioLine
.Adverbs:
-; there are NUM_OAKS_MON_TALK_ADVERBS entries
+; there are NUM_OAKS_POKEMON_TALK_ADVERBS entries
dw .sweetadorably
dw .wigglyslickly
@@ -475,19 +475,19 @@ OaksPkmnTalk9:
jp NextRadioLine
.Adjectives:
-; there are NUM_OAKS_MON_TALK_ADJECTIVES entries
+; there are NUM_OAKS_POKEMON_TALK_ADJECTIVES entries
dw .cute
dw .weird